==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/hr/general.php <==
<?php

    return [
    'accessories'			=> 'Pribor',
    'activated'			    => 'aktiviran',
    'accessory'				=> 'Oprema',
    'accessory_report'		=> 'Izvješće o dodatku',
    'action'                => 'Akcijski',
    'activity_report'		=> 'Izvješće o aktivnostima',
    'address'				=> 'Adresa',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Dodana mjesta',
    'all_assets'			=> 'Sve imovine',
    'all'       			=> 'svi',
    'archived'              => 'Arhivirano',
    'asset_models'			=> 'Modeli imovine',
    'asset_model'			=> 'Model',
    'asset'					=> 'Imovina',
    'asset_report'          => 'Izvješće o aktivi',
    'asset_tag'				=> 'Oznaka imovine',
    'assets_available'		=> 'dostupna imovina',
    'audit'				    => 'Revizija',
    'audit_report'			=> 'Zapisnik revizije',
    'assets'				=> 'Imovina',
    'avatar_delete'         => 'Obriši avatar',
    'avatar_upload'         => 'Učitaj avatar',
    'back'      			=> 'Nazad',
    'bad_data'      		=> 'Ništa nije pronađeno. Možda loši podaci?',
    'bulkaudit'             => 'Skupna revizija',
    'bulkaudit_status'      => 'Status revizije',
    'bulk_checkout'  		=> 'Bulk Checkout',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Otkazati',
    'categories'			=> 'Kategorije',
    'category'				=> 'Kategorija',
    'change' 		        => 'In / Out',
    'changeemail'  			=> 'Promijeni e mail adresu',
    'changepassword'  		=> 'Promijeni zaporku',
    'checkin'  				=> 'Checkin',
    'checkin_from'  		=> 'Prijavite se od tvrtke',
    'checkout'  			=> 'Provjeri',
    'checkouts_count'       => 'Odjave',
    'checkins_count'        => 'Prijave',
    'user_requests_count'   => 'Zahtjevi',
    'city'  				=> 'Grad',
	'click_here'			=> 'Kliknite ovdje',
    'clear_selection'		=> 'Očisti odabir',
    'companies'			    => 'Tvrtke',
    'company'				=> 'Društvo',
    'component'			    => 'sastavni dio',
    'components'			=> 'komponente',
	'complete'				=> 'potpun',
    'consumable'			=> 'potrošni',
    'consumables'			=> 'Potrošni',
    'country'  				=> 'Zemlja',
    'create'				=> 'Izradi novu',
    'created'               => 'Stavka je stvorena',
    'created_asset'			=> 'stvorio imovinu',
    'created_at' 			=> 'Created at',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Ažurirano u',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'struja',
    'custom_report'         => 'Prilagođeno izvješće o aktivi',
    'dashboard'				=> 'kontrolna ploča',
    'days'      			=> 'dana',
    'days_to_next_audit'    => 'Dani za sljedeću reviziju',
    'date'					=> 'Datum',
    'debug_warning'         => 'Upozorenje!',
    'debug_warning_text'    => 'Ova se aplikacija izvodi u načinu rada s omogućenim uklanjanjem pogrešaka. To može otkriti osjetljive podatke ako je aplikacija dostupna vanjskom svijetu. Onemogućite način otklanjanja pogrešaka postavljanjem vrijednosti <code>APP_DEBUG</code> u <code>.env</code> datoteci na <code>false</code>.',
    'delete'  				=> 'Izbrisati',
    'delete_confirm'  		=> 'Jeste li sigurni da želite izbrisati :item?',
    'deleted'  				=> 'izbrisana',
    'delete_seats'  		=> 'Izbrisana mjesta',
    'departments'           => 'odjeli',
    'department'           => 'odjel',
    'deployed'				=> 'razmještene',
    'depreciation_report'	=> 'Izvješće o amortizaciji',
    'details'               => 'Detalji',
    'download'				=> 'Preuzimanje',
    'download_all'				=> 'Download All',
    'depreciation'			=> 'deprecijacija',
    'editprofile'  			=> 'Uredi svoj profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Domena e-pošte',
    'email_format'			=> 'Format e-pošte',
    'email_domain_help'		=> 'Ovo se koristi za generiranje e-adresa prilikom uvoza',
    'filastname_format'			=> 'Prvo početno prezime (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Prezime prezime (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Ime Prezime (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Prezime Prvo slovo imena (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Prvi',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Ime',
    'first_name_format'		=> 'Ime (jane@example.com)',
    'files'                 => 'Datoteke',
    'file_name'				=> 'Datoteka',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Prijenos datoteka',
    'generate'				=> 'Generirati',
     'github_markdown'      => 'Ovo polje prihvaća <a href="https://help.github.com/articles/github-flavored-markdown/">označavanje na Github način</a>.',
    'groups'				=> 'grupe',
    'gravatar_email'        => 'Gravatar adresa e-pošte',
    'history'  			    => 'Povijest',
    'history_for'  			=> 'Povijest za',
    'id'  					=> 'iskaznica',
    'image'                 => 'Slika',
    'image_delete'         	=> 'Izbriši sliku',
    'image_upload'         	=> 'Prenesite sliku',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Uvoz',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Povijest uvoza',
    'asset_maintenance'        => 'Održavanje imovine',
    'asset_maintenance_report' => 'Izvješće o održavanju imovine',
    'asset_maintenances'       => 'Upravljanje imovinom',
    'item'  				=> 'Artikal',
    'insufficient_permissions' => 'Nedovoljna dozvola!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Jezik',
    'last'					=> 'Posljednji',
    'last_login'            => 'Zadnja prijava',
    'last_name'             => 'Prezime',
    'license'				=> 'licenca',
    'license_report'        => 'Izvješće o licenci',
    'licenses_available'	=> 'dostupne licence',
    'licenses'				=> 'licence',
    'list_all'				=> 'Popis svih',
    'loading'				=> 'punjenje',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Ova je značajka onemogućena za demo instalaciju.',
    'location'              => 'Mjesto',
    'locations'				=> 'lokacije',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Odjaviti se',
    'lookup_by_tag'     => 'Pretraživanje pomoću oznake imovine',
    'maintenances'          => 'Održavanje',
    'manufacturer'			=> 'Proizvođač',
    'manufacturers'			=> 'Proizvođači',
    'markdown'				=> 'Ovo polje dopušta <a href="https://help.github.com/articles/github-flavored-markdown/">gordi s okusom "Github "</a>.',
    'min_amt'				=> 'Min. Kol',
    'min_amt_help'	=> 'Minimalni broj stavki koje bi trebale biti dostupne prije nego što se aktivira upozorenje.',
    'model_no'				=> 'Model br.',
    'months'				=> 'mjeseci',
    'moreinfo'				=> 'Više informacija',
    'name'					=> 'Ime',
    'next'					=> 'Sljedeći',
    'next_audit_date'		=> 'Sljedeći datum revizije',
    'last_audit'		    => 'Posljednja revizija',
    'new'					=> 'novi!',
    'no_depreciation'		=> 'Nema amortizacije',
    'no_results'			=> 'Nema rezultata.',
    'no'  					=> 'Ne',
    'notes'  				=> 'Bilješke',
    'order_number'          => 'Broj narudžbe',
    'page_menu'				=> 'Prikazuje se _MENU_ stavki',
    'pagination_info'		=> 'Prikazuje se _START_ do _END_ od _TOTAL_ stavki',
    'pending'				=> 'U tijeku',
    'people'				=> 'narod',
    'per_page'				=> 'Rezultati po stranici',
    'previous'				=> 'prijašnji',
    'processing'			=> 'Obrada',
    'profile'				=> 'Tvoj profil',
    'purchase_cost'                              => 'Trošak nabave',
    'purchase_date'         => 'Datum kupnje',
    'qty'		            => 'Kol',
    'quantity'		        => 'Količina',
    'ready_to_deploy'		=> 'Spremni za implementaciju',
    'recent_activity'		=> 'Nedavna aktivnost',
    'remove_company'        => 'Ukloni Udruženje tvrtki',
    'reports'				=> 'Izvještaji',
    'restored'				=> 'obnovljeno',
    'requested'				=> 'Traženi',
    'request_canceled'      => 'Zahtjev je otkazan',
    'save'  				=> 'Uštedjeti',
    'select'				=> 'Izaberi',
    'search'				=> 'traži',
    'select_category'       => 'Izaberi kategoriju',
    'select_department'       => 'Odaberite Odjel',
    'select_depreciation'	=> 'Odaberite vrstu amortizacije',
    'select_location'		=> 'Odaberite lokaciju',
    'select_manufacturer'	=> 'Odaberite proizvođača',
    'select_model'			=> 'Odaberite model',
    'select_supplier'		=> 'Odaberite dobavljača',
    'select_user'			=> 'Odaberite korisnika',
    'select_date'			=> 'Odaberite datum (GGGG-MM-DD)',
    'select_statuslabel'	=> 'Odaberite Status',
    'select_company'    	=> 'Odaberite tvrtku',
    'select_asset'    		=> 'Odaberite Asset',
    'settings'				=> 'postavke',
    'show_deleted'  		=> 'Prikaži izbrisano',
    'show_current'  		=> 'Prikaži trenutno',
    'sign_in'				=> 'Prijaviti se',
    'signature'             => 'Potpis',
    'skin'       			=> 'Skin',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Neke su značajke onemogućene za ovu instalaciju.',
    'site_name'				=> 'Ime stranice',
    'state'  				=> 'država',
    'status_labels'			=> 'Oznake statusa',
    'status'    			=> 'Status',
    'supplier'              => 'Dobavljač',
    'suppliers'  			=> 'Dobavljači',
    'sure_to_delete'    => 'Jeste li sigurni da želite izbrisati',
    'submit'				=> 'podnijeti',
    'target'                => 'Cilj',
    'time_and_date_display' => 'Prikaz vremena i datuma',
    'total_assets'			=> 'Ukupna imovina',
    'total_licenses'		=> 'ukupne licence',
    'total_accessories'		=> 'ukupni pribor',
    'total_consumables'		=> 'ukupni potrošni materijal',
    'type'  				=> 'Tip',
    'undeployable'			=> 'Un-razmjestiti',
    'unknown_admin'			=> 'Nepoznati administrator',
    'username_format'		=> 'Format korisničkog imena',
    'update'                => 'Ažuriraj',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Uploaded',
    'user'					=> 'Korisnik',
    'accepted'			    => 'priznat',
    'declined'			    => 'odbijeno',
    'unaccepted_asset_report' => 'Neprihvaćene imovine',
    'users'                 => 'Korisnici',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Prikaz dodijeljenih sredstava',
    'website'               => 'Web stranica',
    'welcome'				=> 'Dobrodošli,: ime',
    'years'					=> 'godina',
    'yes' 					=> 'Da',
    'zip'  					=> 'poštanski',
    'noimage'				=> 'Nije prenesena slika niti slika nije pronađena.',
    'token_expired'         => 'Sesija za obrazac istekla je. Molim te pokušaj ponovno.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'Prihvaćam',
    'i_decline'             => 'Odbijam',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/hr/general.php <==
<?php

    return [
    'accessories'			=> 'Pribor',
    'activated'			    => 'aktiviran',
    'accessory'				=> 'Oprema',
    'accessory_report'		=> 'Izvješće o dodatku',
    'action'                => 'Akcijski',
    'activity_report'		=> 'Izvješće o aktivnostima',
    'address'				=> 'Adresa',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Dodana mjesta',
    'all_assets'			=> 'Sve imovine',
    'all'       			=> 'svi',
    'archived'              => 'Arhivirano',
    'asset_models'			=> 'Modeli imovine',
    'asset_model'			=> 'Model',
    'asset'					=> 'Imovina',
    'asset_report'          => 'Izvješće o aktivi',
    'asset_tag'				=> 'Oznaka imovine',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'Revizija',
    'audit_report'			=> 'Zapisnik revizije',
    'assets'				=> 'Imovina',
    'avatar_delete'         => 'Obriši avatar',
    'avatar_upload'         => 'Učitaj avatar',
    'back'      			=> 'Nazad',
    'bad_data'      		=> 'Ništa nije pronađeno. Možda loši podaci?',
    'bulkaudit'             => 'Skupna revizija',
    'bulkaudit_status'      => 'Status revizije',
    'bulk_checkout'  		=> 'Bulk Checkout',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Otkazati',
    'categories'			=> 'Kategorije',
    'category'				=> 'Kategorija',
    'change' 		        => 'In / Out',
    'changeemail'  			=> 'Promijeni e mail adresu',
    'changepassword'  		=> 'Promijeni zaporku',
    'checkin'  				=> 'Checkin',
    'checkin_from'  		=> 'Prijavite se od tvrtke',
    'checkout'  			=> 'Provjeri',
    'checkouts_count'       => 'Odjave',
    'checkins_count'        => 'Prijave',
    'user_requests_count'   => 'Zahtjevi',
    'city'  				=> 'Grad',
    'click_here'			=> 'Kliknite ovdje',
    'clear_selection'		=> 'Očisti odabir',
    'companies'			    => 'Tvrtke',
    'company'				=> 'Društvo',
    'component'			    => 'sastavni dio',
    'components'			=> 'komponente',
    'complete'				=> 'potpun',
    'consumable'			=> 'potrošni',
    'consumables'			=> 'Potrošni',
    'country'  				=> 'Zemlja',
    'create'				=> 'Izradi novu',
    'created'               => 'Stavka je stvorena',
    'created_asset'			=> 'stvorio imovinu',
    'created_at' 			=> 'Created at',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Ažurirano u',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'struja',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Prilagođeno izvješće o aktivi',
    'dashboard'				=> 'kontrolna ploča',
    'days'      			=> 'dana',
    'days_to_next_audit'    => 'Dani za sljedeću reviziju',
    'date'					=> 'Datum',
    'debug_warning'         => 'Upozorenje!',
    'debug_warning_text'    => 'Ova se aplikacija izvodi u načinu rada s omogućenim uklanjanjem pogrešaka. To može otkriti osjetljive podatke ako je aplikacija dostupna vanjskom svijetu. Onemogućite način otklanjanja pogrešaka postavljanjem vrijednosti <code>APP_DEBUG</code> u <code>.env</code> datoteci na <code>false</code>.',
    'delete'  				=> 'Izbrisati',
    'delete_confirm'  		=> 'Jeste li sigurni da želite izbrisati :item?',
    'deleted'  				=> 'izbrisana',
    'delete_seats'  		=> 'Izbrisana mjesta',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'odjeli',
    'department'            => 'odjel',
    'deployed'				=> 'razmještene',
    'depreciation'			=> 'deprecijacija',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Izvješće o amortizaciji',
    'details'               => 'Detalji',
    'download'				=> 'Preuzimanje',
    'download_all'		    => 'Download All',
    'editprofile'  			=> 'Uredi svoj profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Domena e-pošte',
    'email_format'			=> 'Format e-pošte',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Ovo se koristi za generiranje e-adresa prilikom uvoza',
    'error'				    => 'Error',
    'filastname_format'			=> 'Prvo početno prezime (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Prezime prezime (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Ime Prezime (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Prezime Prvo slovo imena (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Prvi',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Ime',
    'first_name_format'		=> 'Ime (jane@example.com)',
    'files'                 => 'Datoteke',
    'file_name'				=> 'Datoteka',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Prijenos datoteka',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Generirati',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'Ovo polje prihvaća <a href="https://help.github.com/articles/github-flavored-markdown/">označavanje na Github način</a>.',
    'groups'				=> 'grupe',
    'gravatar_email'        => 'Gravatar adresa e-pošte',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Povijest',
    'history_for'  			=> 'Povijest za',
    'id'  					=> 'iskaznica',
    'image'                 => 'Slika',
    'image_delete'         	=> 'Izbriši sliku',
    'image_upload'         	=> 'Prenesite sliku',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Uvoz',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Povijest uvoza',
    'asset_maintenance'        => 'Održavanje imovine',
    'asset_maintenance_report' => 'Izvješće o održavanju imovine',
    'asset_maintenances'       => 'Upravljanje imovinom',
    'item'  				=> 'Artikal',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Nedovoljna dozvola!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Jezik',
    'last'					=> 'Posljednji',
    'last_login'            => 'Zadnja prijava',
    'last_name'             => 'Prezime',
    'license'				=> 'licenca',
    'license_report'        => 'Izvješće o licenci',
    'licenses_available'	=> 'dostupne licence',
    'licenses'				=> 'licence',
    'list_all'				=> 'Popis svih',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Ova je značajka onemogućena za demo instalaciju.',
    'location'              => 'Mjesto',
    'locations'				=> 'lokacije',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Odjaviti se',
    'lookup_by_tag'     => 'Pretraživanje pomoću oznake imovine',
    'maintenances'          => 'Održavanje',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Proizvođač',
    'manufacturers'			=> 'Proizvođači',
    'markdown'				=> 'Ovo polje dopušta <a href="https://help.github.com/articles/github-flavored-markdown/">gordi s okusom "Github "</a>.',
    'min_amt'				=> 'Min. Kol',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Model br.',
    'months'				=> 'mjeseci',
    'moreinfo'				=> 'Više informacija',
    'name'					=> 'Ime',
    'new_password'          => 'New Password',
    'next'					=> 'Sljedeći',
    'next_audit_date'		=> 'Sljedeći datum revizije',
    'last_audit'		    => 'Posljednja revizija',
    'new'					=> 'novi!',
    'no_depreciation'		=> 'Nema amortizacije',
    'no_results'			=> 'Nema rezultata.',
    'no'  					=> 'Ne',
    'notes'  				=> 'Bilješke',
    'order_number'          => 'Broj narudžbe',
    'page_menu'				=> 'Prikazuje se _MENU_ stavki',
    'pagination_info'		=> 'Prikazuje se _START_ do _END_ od _TOTAL_ stavki',
    'pending'				=> 'U tijeku',
    'people'				=> 'narod',
    'per_page'				=> 'Rezultati po stranici',
    'previous'				=> 'prijašnji',
    'processing'			=> 'Obrada',
    'profile'				=> 'Tvoj profil',
    'purchase_cost'                              => 'Trošak nabave',
    'purchase_date'         => 'Datum kupnje',
    'qty'		            => 'Kol',
    'quantity'		        => 'Količina',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Spremni za implementaciju',
    'recent_activity'		=> 'Nedavna aktivnost',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Ukloni Udruženje tvrtki',
    'reports'				=> 'Izvještaji',
    'restored'				=> 'obnovljeno',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Traženi',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Zahtjev je otkazan',
    'save'  				=> 'Uštedjeti',
    'select'				=> 'Izaberi',
    'select_all'            => 'Select All',
    'search'				=> 'traži',
    'select_category'       => 'Izaberi kategoriju',
    'select_department'     => 'Odaberite Odjel',
    'select_depreciation'	=> 'Odaberite vrstu amortizacije',
    'select_location'		=> 'Odaberite lokaciju',
    'select_manufacturer'	=> 'Odaberite proizvođača',
    'select_model'			=> 'Odaberite model',
    'select_supplier'		=> 'Odaberite dobavljača',
    'select_user'			=> 'Odaberite korisnika',
    'select_date'			=> 'Odaberite datum (GGGG-MM-DD)',
    'select_statuslabel'	=> 'Odaberite Status',
    'select_company'    	=> 'Odaberite tvrtku',
    'select_asset'    		=> 'Odaberite Asset',
    'settings'				=> 'postavke',
    'show_deleted'  		=> 'Prikaži izbrisano',
    'show_current'  		=> 'Prikaži trenutno',
    'sign_in'				=> 'Prijaviti se',
    'signature'             => 'Potpis',
    'skin'       			=> 'Skin',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Neke su značajke onemogućene za ovu instalaciju.',
    'site_name'				=> 'Ime stranice',
    'state'  				=> 'država',
    'status_labels'			=> 'Oznake statusa',
    'status'    			=> 'Status',
    'supplier'              => 'Dobavljač',
    'suppliers'  			=> 'Dobavljači',
    'sure_to_delete'    => 'Jeste li sigurni da želite izbrisati',
    'submit'				=> 'podnijeti',
    'target'                => 'Cilj',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Prikaz vremena i datuma',
    'total_assets'			=> 'Ukupna imovina',
    'total_licenses'		=> 'ukupne licence',
    'total_accessories'		=> 'ukupni pribor',
    'total_consumables'		=> 'ukupni potrošni materijal',
    'type'  				=> 'Tip',
    'undeployable'			=> 'Un-razmjestiti',
    'unknown_admin'			=> 'Nepoznati administrator',
    'username_format'		=> 'Format korisničkog imena',
    'update'                => 'Ažuriraj',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Uploaded',
    'user'					=> 'Korisnik',
    'accepted'			    => 'priznat',
    'declined'			    => 'odbijeno',
    'unaccepted_asset_report' => 'Neprihvaćene imovine',
    'users'                 => 'Korisnici',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Prikaz dodijeljenih sredstava',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Web stranica',
    'welcome'				=> 'Dobrodošli,: ime',
    'years'					=> 'godina',
    'yes' 					=> 'Da',
    'zip'  					=> 'poštanski',
    'noimage'				=> 'Nije prenesena slika niti slika nije pronađena.',
    'token_expired'         => 'Sesija za obrazac istekla je. Molim te pokušaj ponovno.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'Prihvaćam',
    'i_decline'             => 'Odbijam',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
